@@ -1,7 +1,10 @@
+#!/usr/bin/env python
 import unittest
 import tempfile
+
 from starcluster.config import StarClusterConfig
-from starcluster.tests.templates.config import config_test_template, default_config
+from starcluster.tests.templates import config
+
 
 class StarClusterTest(unittest.TestCase):
 
@@ -12,18 +15,22 @@ class StarClusterTest(unittest.TestCase):
         """ Returns (valid) default test config """
         if not self.__cfg:
             tmp_file = tempfile.NamedTemporaryFile()
-            tmp_file.write(config_test_template % default_config)
+            tmp_file.write(config.config_test_template % config.default_config)
             tmp_file.flush()
-            self.__cfg = StarClusterConfig(tmp_file.name, cache=True); self.__cfg.load()
+            self.__cfg = StarClusterConfig(tmp_file.name, cache=True).load()
         return self.__cfg
 
+    def get_config(self, contents, cache=False):
+        tmp_file = tempfile.NamedTemporaryFile()
+        tmp_file.write(contents)
+        tmp_file.flush()
+        cfg = StarClusterConfig(tmp_file.name, cache=cache).load()
+        return cfg
+
     def get_custom_config(self, **kwargs):
         """ Returns default test config modified by kwargs """
-        tmp_file = tempfile.NamedTemporaryFile()
-        kwords = {}; 
-        kwords.update(default_config)
+        kwords = {}
+        kwords.update(config.default_config)
         kwords.update(kwargs)
-        tmp_file.write(config_test_template % kwords);
-        tmp_file.flush()
-        cfg = StarClusterConfig(tmp_file.name, cache=True); cfg.load()
+        cfg = self.get_config(config.config_test_template % kwords)
         return cfg
